#
# spec file for package python-primp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-primp
Version:        0.7.0
Release:        1.3
Summary:        HTTP client that can impersonate web browsers
License:        MIT
URL:            https://github.com/deedy5/primp
Source0:        https://files.pythonhosted.org/packages/source/p/primp/primp-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  %{python_module maturin >= 1.5}
BuildRequires:  %{python_module pip}
BuildRequires:  cargo-packaging
BuildRequires:  clang-devel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  llvm
BuildRequires:  openssl
BuildRequires:  python-rpm-macros

%python_subpackages

%description
The fastest python HTTP client that can impersonate web browsers, mimicking
their headers and 'TLS/JA3/JA4/HTTP2' fingerprints

%prep
%autosetup -p1 -n primp-%{version} -a1

%build
export CARGO_NET_OFFLINE=true
export CARGO_PROFILE_RELEASE_DEBUG=full
export CARGO_PROFILE_RELEASE_SPLIT_DEBUGINFO=off
export CARGO_PROFILE_RELEASE_STRIP=false
export C_INCLUDE_PATH=/usr/lib64/gcc/%_arch-suse-linux/%gcc_version/include
%pyproject_wheel

%install
export CARGO_NET_OFFLINE=true
export CARGO_PROFILE_RELEASE_DEBUG=full
export CARGO_PROFILE_RELEASE_SPLIT_DEBUGINFO=off
export CARGO_PROFILE_RELEASE_STRIP=false
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# NOTE: don't run the tests as they required access to internet by trying to
# connect to "https://httpbin.org/anything".

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/primp
%{python_sitearch}/primp-%{version}*-info

%changelog
* Tue Nov 19 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.0:
  * Using the `pythonize` crate to handle data and json
    parameters, and return the responce as json
  * Bump rquest to v0.27, cargo update
- update to 0.6.5:
  * Bump rquest to v0.26
  * Readme: impersonate parameter - add "chrome_130"
- update to 0.6.4:
  * ca_cert_file: updated the code to match the changes in the
    upstream package
  * Bump html2text to v0.13
* Sat Sep 28 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.3:
  * README: impersonate - add "chrome_129", "safari_18",
    "safari_ipad_18"
- update to 0.6.2:
  * README: impersonate param - add chrome_128
* Mon Sep  9 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.1:
  * Use Exception to raise error
  * CI: [linux] [x_86_64] - use `zig` to build for manylinux_2_17
  * params data, json: replace clone() with as_unbound()
  * recode headers
  * Remove PyException
  * README: update precompiled wheels compatibility info
* Fri Aug 23 2024 Guang Yee <gyee@suse.com>
- Version v0.6.0
  * CI: bugfix after dependencies update by @deedy5
  * Use anyhow for error handling by @deedy5
  * Improve response code by @deedy5
  * [Client]: add ca_cert_file parameter by @deedy5
  * [Utils] Recode fn json_dumps, json_loads, url_encode by @deedy5
  * [html2text] Response object: 1) add attribute text_rich
  * [logging]: send Rust log messages to Python
  * small code improvements
